@@ -106,6 +106,7 @@ struct _GcalWindow
   GtkWidget          *agenda_view;
   GtkWidget          *date_chooser;
   GtkWidget          *action_bar;
+  GcalToolbarEnd     *toolbar_end;
 
   /* header_bar widets */
   GtkWidget          *calendars_button;
@@ -311,6 +312,17 @@ load_css_providers (GcalWindow *self)
                                               GTK_STYLE_PROVIDER_PRIORITY_APPLICATION + 1);
 }
 
+static void
+show_widget (GtkWidget *widget)
+{
+  gtk_widget_set_visible (widget, TRUE);
+}
+
+static void
+hide_widget (GtkWidget *widget)
+{
+  gtk_widget_set_visible (widget, FALSE);
+}
 
 /*
  * Callbacks
@@ -323,7 +335,7 @@ on_show_calendars_action_activated (GSimpleAction *action,
 {
   GcalWindow *window = GCAL_WINDOW (user_data);
 
-  gtk_widget_show (window->calendar_management_dialog);
+  gtk_widget_set_visible (window->calendar_management_dialog, TRUE);
 }
 
 static void
@@ -395,7 +407,7 @@ on_window_new_event_cb (GSimpleAction *action,
   event = gcal_event_new (default_calendar, comp, NULL);
 
   gcal_event_editor_dialog_set_event (self->event_editor, event, TRUE);
-  gtk_widget_show (GTK_WIDGET (self->event_editor));
+  gtk_widget_set_visible (GTK_WIDGET (self->event_editor), TRUE);
 }
 
 static void
@@ -464,7 +476,8 @@ on_window_undo_delete_event_cb (GSimpleAction *action,
   widgets = gcal_view_get_children_by_uuid (GCAL_VIEW (self->views[self->active_view]),
                                             modifier,
                                             gcal_event_get_uid (event));
-  g_list_foreach (widgets, (GFunc) gtk_widget_show, NULL);
+
+  g_list_foreach (widgets, (GFunc) show_widget, NULL);
 
   g_clear_object (&self->delete_event_toast);
 
@@ -590,7 +603,7 @@ edit_event (GcalQuickAddPopover *popover,
             GcalWindow          *window)
 {
   gcal_event_editor_dialog_set_event (window->event_editor, event, TRUE);
-  gtk_widget_show (GTK_WIDGET (window->event_editor));
+  gtk_widget_set_visible (GTK_WIDGET (window->event_editor), TRUE);
 }
 
 static void
@@ -611,7 +624,7 @@ create_event_detailed_cb (GcalView *view,
   event = gcal_event_new (default_calendar, comp, NULL);
 
   gcal_event_editor_dialog_set_event (window->event_editor, event, TRUE);
-  gtk_widget_show (GTK_WIDGET (window->event_editor));
+  gtk_widget_set_visible (GTK_WIDGET (window->event_editor), TRUE);
 
   g_clear_object (&comp);
 }
@@ -715,9 +728,9 @@ on_event_editor_dialog_remove_event_cb (GcalEventEditorDialog *edit_dialog,
   agenda_view_widgets = gcal_view_get_children_by_uuid (GCAL_VIEW (self->agenda_view), modifier, gcal_event_get_uid (event));
   date_chooser_widgets = gcal_view_get_children_by_uuid (GCAL_VIEW (self->date_chooser), modifier, gcal_event_get_uid (event));
 
-  g_list_foreach (widgets, (GFunc) gtk_widget_hide, NULL);
-  g_list_foreach (agenda_view_widgets, (GFunc) gtk_widget_hide, NULL);
-  g_list_foreach (date_chooser_widgets, (GFunc) gtk_widget_hide, NULL);
+  g_list_foreach (widgets, (GFunc) hide_widget, NULL);
+  g_list_foreach (agenda_view_widgets, (GFunc) hide_widget, NULL);
+  g_list_foreach (date_chooser_widgets, (GFunc) hide_widget, NULL);
 
   GCAL_EXIT;
 }
@@ -843,6 +856,7 @@ gcal_window_constructed (GObject *object)
   g_object_bind_property (self, "context", self->date_chooser, "context", G_BINDING_DEFAULT | G_BINDING_SYNC_CREATE);
   g_object_bind_property (self, "context", self->event_editor, "context", G_BINDING_DEFAULT | G_BINDING_SYNC_CREATE);
   g_object_bind_property (self, "context", self->quick_add_popover, "context", G_BINDING_DEFAULT | G_BINDING_SYNC_CREATE);
+  g_object_bind_property (self, "context", self->toolbar_end, "context", G_BINDING_DEFAULT | G_BINDING_SYNC_CREATE);
 
   /* CSS */
   load_css_providers (self);
@@ -871,7 +885,7 @@ gcal_window_set_property (GObject      *object,
     {
     case PROP_ACTIVE_VIEW:
       self->active_view = g_value_get_enum (value);
-      gtk_widget_show (self->views[self->active_view]);
+      gtk_widget_set_visible (self->views[self->active_view], TRUE);
       adw_view_stack_set_visible_child (self->views_stack, self->views[self->active_view]);
       break;
 
@@ -1032,6 +1046,7 @@ gcal_window_class_init (GcalWindowClass *klass)
   gtk_widget_class_bind_template_child (widget_class, GcalWindow, quick_add_popover);
   gtk_widget_class_bind_template_child (widget_class, GcalWindow, calendar_management_dialog);
   gtk_widget_class_bind_template_child (widget_class, GcalWindow, overlay);
+  gtk_widget_class_bind_template_child (widget_class, GcalWindow, toolbar_end);
   gtk_widget_class_bind_template_child (widget_class, GcalWindow, views_stack);
   gtk_widget_class_bind_template_child (widget_class, GcalWindow, views_switcher);
   gtk_widget_class_bind_template_child (widget_class, GcalWindow, weather_settings);
@@ -1119,13 +1134,12 @@ void
 gcal_window_set_search_query (GcalWindow  *self,
                               const gchar *query)
 {
-  //GtkEntry *entry;
+  GtkWidget *search_button;
 
   g_return_if_fail (GCAL_IS_WINDOW (self));
 
-  // TODO
-  //entry = gcal_search_button_get_entry (self->search_button);
-  //gtk_entry_set_text (GTK_ENTRY (entry), query);
+  search_button = gcal_toolbar_end_get_search_button (self->toolbar_end);
+  gcal_search_button_search (GCAL_SEARCH_BUTTON (search_button), query);
 }
 
 /**
