@@ -25,7 +25,7 @@
 #include "gcal-range-tree.h"
 #include "gcal-timeline-subscriber.h"
 #include "gcal-utils.h"
-#include "gcal-view.h"
+#include "gcal-view-private.h"
 
 #include <adwaita.h>
 #include <glib/gi18n.h>
@@ -193,13 +193,6 @@ new_date_header_string (GDateTime *date)
  * Callbacks
  */
 
-static void
-on_event_activated (GcalAgendaView *self,
-                    GtkWidget      *widget)
-{
-  g_signal_emit_by_name (self, "event-activated", widget);
-}
-
 static void
 stack_visible_child_changed_cb (AdwViewStack   *stack,
                                 GParamSpec     *pspec,
@@ -370,7 +363,7 @@ update_header (GtkListBoxRow *row,
       g_autofree gchar *end_label = NULL;
       if (gcal_date_time_compare_date (start, today) == 0)
         {
-          label = g_strdup ("On-going");
+          label = g_strdup (_("On-going"));
         }
       else
         {
@@ -495,6 +488,13 @@ gcal_view_interface_init (GcalViewInterface *iface)
  * GcalTimelineSubscriber iface
  */
 
+static void
+on_event_widget_activated_cb (GcalEventWidget *event_widget,
+                              GcalAgendaView  *self)
+{
+  gcal_view_event_activated (GCAL_VIEW (self), event_widget);
+}
+
 static GcalRange*
 gcal_agenda_view_get_range (GcalTimelineSubscriber *subscriber)
 {
@@ -547,8 +547,7 @@ gcal_agenda_view_add_event (GcalTimelineSubscriber *subscriber,
                              gcal_event_get_range (event),
                              child_data_new (row, event, self));
 
-  /* FIXME */
-  /* g_signal_connect (widget, "activate", G_CALLBACK (on_event_widget_activated_cb), self); */
+  g_signal_connect (widget, "activate", G_CALLBACK (on_event_widget_activated_cb), self);
 
   gtk_list_box_append (GTK_LIST_BOX (self->list_box), row);
 
@@ -726,8 +725,6 @@ gcal_agenda_view_class_init (GcalAgendaViewClass *klass)
   gtk_widget_class_bind_template_child (widget_class, GcalAgendaView, no_events_row);
   gtk_widget_class_bind_template_child (widget_class, GcalAgendaView, scrolled_window);
 
-  gtk_widget_class_bind_template_callback (widget_class, on_event_activated);
-
   gtk_widget_class_set_css_name (widget_class, "agenda-view");
 }
 
